///////////////////////////////////////////////////////////////////////////////
// DialogLayout.java
//  Copyright (C) Neuron Computing 2004. All rights reserved.

import java.awt.*;
import java.awt.event.*;
import java.lang.System;

/////////////////////////////////////////////////////////////////////////////
// DialogLayout
class DialogLayout implements LayoutManager2, ActionListener
{
	protected JFormContainer m_form;
	protected Dialog m_dialog;
	protected boolean m_inValidation = false;

// Construction
public DialogLayout()
{
	m_form = new JFormContainer();
	m_form.addActionListener(this);
	m_form.setLayout(this);
}

// Methods
public int doModal(Frame owner)
{
	m_dialog = new Dialog(owner, true);
	m_dialog.add("Center", m_form);
	m_dialog.setTitle(m_form.getTitle());
	// Show dialog
	updateData(false);

	m_dialog.pack();
	m_dialog.show();

	updateData(true);
	m_dialog.removeNotify();
	m_dialog = null;

	return getResult();
}

public int getResult()
{
	return Integer.parseInt(m_form.getResult());
}

public void doBrowse(Frame owner)
{
	m_dialog = new Dialog(owner, false);
	m_dialog.add("Center", m_form);
	m_dialog.setTitle(m_form.getTitle());
	// Show dialog
	updateData(false);
	m_dialog.pack();
	m_dialog.show();
}

public void endDialog(int result)
{
	m_form.endDialog(String.valueOf(result));
}

public Container getContainer()
{
	return m_form;
}

	public static final int ok		= 1;
	public static final int cancel	= 2;
	public static final int abort	= 3;
	public static final int retry	= 4;
	public static final int ignore	= 5;
	public static final int yes		= 6;
	public static final int no		= 7;
	public static final int close	= 8;
	public static final int help	= 9;

	public static final int left = 0;
	public static final int below = 0;
	public static final int right = 1;
	public static final int above = 2;
	public static final int leftBelow = 0;
	public static final int rightBelow = 1;
	public static final int leftAbove = 2;
	public static final int rightAbove = 3;

public void setTitle(String title)
{
	m_form.setTitle(title);
}

// Initialization
public void add(int id, String text)
{
	Component comp = m_form.getComponent(id);
	if (comp == null)
		throw new IllegalArgumentException();
	// List component
	if (comp instanceof List)
	{
		((List)comp).add(text);
		return;
	}
	// Choice
	if (comp instanceof Choice)
	{
		((Choice)comp).add(text);
		return;
	}
}

public void add(int id, String text[], int count)
{
	Component comp = m_form.getComponent(id);
	if (comp == null)
		throw new IllegalArgumentException();
	// List component
	if (comp instanceof List)
	{
		List compList = (List)comp;
		for (int i=0; i<count; i++)
		{
			compList.add(text[i]);
		}
		return;
	}
	// Choice
	if (comp instanceof Choice)
	{
		Choice compChoice = (Choice)comp;
		for (int i=0; i<count; i++)
		{
			compChoice.add(text[i]);
		}
		return;
	}
}

	// Data transfer
	public void setText(int id, String text)
		{m_form.setText(id, text);}
	public String getText(int id)
		{return m_form.getText(id);}

	public void setBoolean(int id, boolean value)
		{m_form.setBoolean(id, value);}
	public boolean getBoolean(int id)
		{return m_form.getBoolean(id);}

public int getSel(int id)
{
	Component comp = m_form.getComponent(id);
	if (comp == null)
		throw new IllegalArgumentException();
	// List component
	if (comp instanceof List)
	{
		return ((List)comp).getSelectedIndex();
	}
	// Choice
	if (comp instanceof Choice)
	{
		return ((Choice)comp).getSelectedIndex();
	}
	return -1;
}

public void setSel(int id, int index)
{
	Component comp = m_form.getComponent(id);
	if (comp == null)
		throw new IllegalArgumentException();
	// List component
	if (comp instanceof List)
	{
		((List)comp).select(index);
		return;
	}
	// Choice
	if (comp instanceof Choice)
	{
		((Choice)comp).select(index);
		return;
	}
}

// Size
public void setDialogHeight(int height)
{
	if (m_dialog == null)
		return;
	Insets insets = m_dialog.getInsets();
	Dimension dim = m_dialog.getSize();
	m_dialog.setSize(dim.width, height+insets.top+insets.bottom);
}

public void setDialogHeightUpTo(int id)
{
	Component comp = m_form.getComponent(id);
	if (comp == null)
		throw new IllegalArgumentException();
	Rectangle rect = comp.getBounds();
	Dimension margins = m_form.getMargins();
	setDialogHeight(rect.y+rect.height+margins.height);
}

public void hideOkCancelButtons()
{
	Component comp = m_form.getComponent(0);
	if (comp instanceof Button)
		comp.setVisible(false);
	comp = m_form.getComponent(1);
	if (comp instanceof Button)
		comp.setVisible(false);
}

	// DialogLayout methods
	public void updateData(boolean save)
		{}
	protected void processAction(int action)
		{}
	protected void layout()
		{}

protected void invalidateLayout()
{
	int count = m_form.countComponents();
	for (int i=0; i<count; i++)
	{
		Component comp = m_form.getComponent(i);
		comp.setBounds(0, 0, 0, 0);
	}
}

// IActionListener
public void actionPerformed(ActionEvent e)
{
	String strCommand = e.getActionCommand();
	int command = Integer.parseInt(strCommand);
	processAction(command);
}

	// ILayoutManager
	public void addLayoutComponent(String name, Component comp)
		{}
	public void removeLayoutComponent(Component comp)
		{}
public Dimension minimumLayoutSize(Container target)
{
	System.out.println("minimumLayoutSize");
	return preferredLayoutSize(target);
}

public Dimension preferredLayoutSize(Container target)
{
	System.out.println("preferredLayoutSize");
	layoutContainer(target);
	return m_form.getInternalSize();
}

public void layoutContainer(Container target)
{
	System.out.println("layoutContainer start");
	if (!m_form.isValid() && !m_inValidation)
	{
		m_inValidation = true;
		invalidateLayout(target);
		layout();
		m_inValidation = false;
	}
	System.out.println("layoutContainer end");
}

	// ILayoutManager2
	public void addLayoutComponent(Component comp, Object constraints)
		{}
	public Dimension maximumLayoutSize(Container target)
		{return preferredLayoutSize(target);}
	public float getLayoutAlignmentX(Container target)
		{return 0.5F;}
	public float getLayoutAlignmentY(Container target)
		{return 0.5F;}
public void invalidateLayout(Container target)
{
	System.out.println("invalidateLayout");
	invalidateLayout();
}
};

class FixedDialogLayout extends DialogLayout
{
protected void invalidateLayout()
	{}
}
